@@ -6,11 +6,15 @@ use vars qw(@ISA $VERSION);
 use DynaLoader;
 
 BEGIN {
-    $VERSION = '4.06';
+    $VERSION = '4.08';
     @ISA     = qw(DynaLoader);
     __PACKAGE__->bootstrap;
 }
 
+END {
+    _global_cleanup();
+}
+
 1;
 
 __END__
@@ -242,6 +246,10 @@ Only used internally, not exposed through the public API.
 
 Not implemented.
 
+=item curl_global_cleanup
+
+Only used internally and called automatically upon exit.
+
 =item curl_slist_append
 
 Only used internally, not exposed through the public API.
@@ -267,19 +275,24 @@ than it's C counterpart. Please see the section about WWW::Curl::Multi above.
 
 =head1 USAGE CASES
 
-The standard Perl WWW module, LWP should be used in most cases to work with
-HTTP or FTP from Perl. However, there are some cases where LWP doesn't
-perform well. One is speed and the other is parallelism. WWW::Curl is much faster,
-uses much less CPU cycles and it's capable of non-blocking parallel requests.
+WWW::Curl is a thin binding on top of libcurl, to make using libcurl possible from Perl land.
+Because of this, the module is less like Perl and more like C in coding style.
+
+There is a new module, L<http://search.cpan.org/perldoc?WWW::Curl::Simple>,
+which wraps this module into a more Perlish and userfriendly package.
+
+The standard Perl WWW module, LWP should probably be used in most cases to work with HTTP or FTP from Perl.
+However, there are some cases where LWP doesn't perform well. One is speed and the other is parallelism. 
+WWW::Curl is much faster, uses much less CPU cycles and it's capable of non-blocking parallel requests.
 
 In some cases, for example when building a web crawler, cpu usage and parallel downloads are
 important considerations. It can be desirable to use WWW::Curl to do the heavy-lifting of
 a large number of downloads and wrap the resulting data into a Perl-friendly structure by
-HTTP::Response.
+HTTP::Response or use WWW::Curl::Simple to do that for you.
 
 =head1 CHANGES
 
-Version 4.01 - 4.06 adds several bugfixes and extends functionality coverage. See Changes file.
+Version 4.01 - 4.07 adds several bugfixes and extends functionality coverage. See Changes file.
 
 Version 4.00 added new documentation, the build system changed to Module::Install,
 the test suite was rewritten to use Test::More, a new calling syntax for WWW::Curl::Multi
@@ -311,7 +324,8 @@ reworked from the previous Curl::easy release (1.21) by Cris Bailiff.
 
 =head1 AUTHORS
 
-Currently maintained by Cris Bailiff <c.bailiff+curl at devsecure.com>
+Currently maintained by Cris Bailiff <c.bailiff+curl at devsecure.com> and
+Balint Szilakszi <szbalint at cpan.org>.
 
 Original Author Georg Horn <horn@koblenz-net.de>, with additional callback,
 pod and test work by Cris Bailiff <c.bailiff+curl@devsecure.com> and
@@ -321,7 +335,7 @@ repackaged the module into a more modern form.
 
 =head1 COPYRIGHT
 
-Copyright (C) 2000-2005,2008 Daniel Stenberg, Cris Bailiff,
+Copyright (C) 2000-2005,2008,2009 Daniel Stenberg, Cris Bailiff,
 Sebastian Riedel, Balint Szilakszi et al.
 
 You may opt to use, copy, modify, merge, publish, distribute and/or sell
@@ -331,4 +345,8 @@ pick one of these licenses.
 
 =head1 SEE ALSO
 
-http://curl.haxx.se
+L<http://curl.haxx.se>
+
+L<http://search.cpan.org/perldoc?WWW::Curl::Simple>
+
+The development source code is also available: L<http://github.com/szbalint/WWW--Curl/tree/master>
